@@ -1,7 +1,7 @@
 import kdp_api
 
-from kdp_api.api.authentication_api import Authentication
-from kdp_api.api.authentication_api import AuthenticationApi
+from kdp_api.api.authenticate_api import Authentication
+from kdp_api.api.authenticate_api import AuthenticateApi
 from kdp_api.model.authentication_sso import AuthenticationSSO
 from kdp_connector.configuration.keycloak_authentication import KeycloakAuthentication
 from kdp_connector.configuration.proxy_authentication import ProxyAuthentication
@@ -25,7 +25,7 @@ class AuthenticationUtil(object):
         """
 
         with kdp_api.ApiClient(config) as api_client:
-            api_instance = AuthenticationApi(api_client)
+            api_instance = AuthenticateApi(api_client)
 
             authentication = Authentication(strategy=strategy, email=email, password=password, workspaceId=workspace_id)
             return api_instance.post_authentication(authentication=authentication)
@@ -45,7 +45,7 @@ class AuthenticationUtil(object):
         """
 
         with kdp_api.ApiClient(config) as api_client:
-            api_instance = AuthenticationApi(api_client)
+            api_instance = AuthenticateApi(api_client)
 
             authentication = ProxyAuthentication(strategy=strategy, first_name=first_name, workspace_id=workspace_id)
             return api_instance.post_authentication(authentication=authentication)
@@ -63,13 +63,12 @@ class AuthenticationUtil(object):
           :rtype: AuthenticationDetails
       """
 
-      keycloak_token =  keycloak.get_keycloak_token()
-      print(f'keycloak_token: {keycloak_token}')
+      keycloak_token = keycloak.get_keycloak_token()
       with kdp_api.ApiClient(config) as api_client:
-        api_instance = AuthenticationApi(api_client)
-        authentication = AuthenticationSSO(strategy="keycloak", access_token=keycloak_token, email='', password='')
+        api_instance = AuthenticateApi(api_client)
+        authentication = AuthenticationSSO(strategy="keycloak", access_token=keycloak_token)
 
-        return api_instance.post_authentication_sso(authentication_sso=authentication,workspace_id=workspace_id)
+        return api_instance.post_authentication_sso(authentication_sso=authentication, workspace_id=workspace_id)
 
 
 
